==> vue-icon-3.21.0.tgz: package/lib/loading-shadow.js <==
import { svg } from "@opentinyvue/vue-common";
import { openBlock, createElementBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  viewBox: "0 0 15.8 15.8",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "defs",
  {
    fill: "none"
  },
  [/* @__PURE__ */ createElementVNode("linearGradient", {
    x1: "20.263",
    y1: "7.9",
    x2: "4.236",
    y2: "0",
    id: "loading-shadow_svg__a",
    gradientUnits: "userSpaceOnUse"
  }, [/* @__PURE__ */ createElementVNode("stop", {
    offset: ".001",
    "stop-color": "#FFF",
    "stop-opacity": "0"
  }), /* @__PURE__ */ createElementVNode("stop", {
    offset: ".975",
    "stop-color": "#FFF"
  })])],
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "mask",
  {
    fill: "none",
    id: "loading-shadow_svg__b",
    "mask-type": "alpha",
    maskUnits: "userSpaceOnUse",
    x: "0",
    y: "0"
  },
  [/* @__PURE__ */ createElementVNode("path", {
    d: "M7.9 0c.49 0 .9.4.9.89 0 .5-.41.91-.9.91-3.37 0-6.1 2.73-6.1 6.09C1.8 11.26 4.53 14 7.9 14c3.36 0 6.1-2.74 6.1-6.11a.9.9 0 0 1 1.8 0c0 4.37-3.54 7.91-7.9 7.91-4.37 0-7.9-3.54-7.9-7.91C0 3.53 3.53 0 7.9 0Z",
    fill: "url(#loading-shadow_svg__a)"
  }, [/* @__PURE__ */ createElementVNode("animateTransform", {
    attributeName: "transform",
    attributeType: "XML",
    type: "rotate",
    from: "0 7.9 7.9",
    to: "360 7.9 7.9",
    dur: "1s",
    repeatCount: "indefinite"
  })])],
  -1
  /* HOISTED */
);
var _hoisted_4 = /* @__PURE__ */ createElementVNode(
  "g",
  {
    mask: "url(#loading-shadow_svg__b)"
  },
  [/* @__PURE__ */ createElementVNode("path", {
    d: "M-.1 15.89h16v-16h-16v16Z",
    "fill-rule": "evenodd"
  })],
  -1
  /* HOISTED */
);
var _hoisted_5 = [_hoisted_2, _hoisted_3, _hoisted_4];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_5));
}
var LoadingShadow = {
  render
};
var index = function index2() {
  return svg({
    name: "IconLoadingShadow",
    component: LoadingShadow
  })();
};
export {
  index as default
};

==> vue-icon-3.23.0.tgz: package/lib/loading-shadow.js <==
import { svg } from "@opentiny/vue-common";
import { createElementBlock, openBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 32 32"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "defs",
  {
    fill: "none"
  },
  [/* @__PURE__ */ createElementVNode("linearGradient", {
    id: "loading-shadow_svg__a",
    x1: "-1285.88",
    y1: "25.63",
    x2: "-1286.89",
    y2: "25.13",
    gradientTransform: "matrix(29.6 0 0 29.6 38096.4 -732.8)",
    gradientUnits: "userSpaceOnUse"
  }, [/* @__PURE__ */ createElementVNode("stop", {
    offset: "0",
    "stop-color": "#191919",
    "stop-opacity": "0"
  }), /* @__PURE__ */ createElementVNode("stop", {
    offset: "1",
    "stop-color": "#191919"
  })])],
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "mask",
  {
    fill: "none",
    id: "loading-shadow_svg__b",
    "mask-type": "alpha",
    maskUnits: "userSpaceOnUse",
    x: "0",
    y: "0"
  },
  [/* @__PURE__ */ createElementVNode("path", {
    fill: "url(#loading-shadow_svg__a)",
    d: "M16 1.2c1 0 1.8.8 1.8 1.8S17 4.8 16 4.8C9.8 4.8 4.8 9.8 4.8 16s5 11.2 11.2 11.2 11.2-5 11.2-11.2c0-1 .8-1.8 1.8-1.8s1.8.8 1.8 1.8c0 8.2-6.6 14.8-14.8 14.8S1.2 24.2 1.2 16 7.8 1.2 16 1.2Z"
  }, [/* @__PURE__ */ createElementVNode("animateTransform", {
    attributeName: "transform",
    attributeType: "XML",
    type: "rotate",
    from: "0 16 16",
    to: "360 16 16",
    dur: "1s",
    repeatCount: "indefinite"
  })])],
  -1
  /* HOISTED */
);
var _hoisted_4 = /* @__PURE__ */ createElementVNode(
  "g",
  {
    mask: "url(#loading-shadow_svg__b)"
  },
  [/* @__PURE__ */ createElementVNode("path", {
    d: "M-.1 32H32V-.11H-.1V32Z",
    "fill-rule": "evenodd"
  })],
  -1
  /* HOISTED */
);
var _hoisted_5 = [_hoisted_2, _hoisted_3, _hoisted_4];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_5));
}
var LoadingShadow = {
  render
};
var index = function index2() {
  return svg({
    name: "IconLoadingShadow",
    component: LoadingShadow
  })();
};
export {
  index as default
};
